@@ -32,6 +32,7 @@
 #include <string.h>
 #include <errno.h>
 
+#include "gtkcmoptionmenu.h"
 #include "main.h"
 #include "prefs_gtk.h"
 #include "prefs_matcher.h"
@@ -89,7 +90,9 @@ static struct Matcher {
 	GtkWidget *numeric_label;
 	GtkWidget *addressbook_folder_combo;
 	GtkWidget *case_checkbtn;
+#ifndef G_OS_WIN32
 	GtkWidget *regexp_checkbtn;
+#endif
 	GtkWidget *color_optmenu;
 
 	GtkWidget *test_btn;
@@ -421,7 +424,7 @@ void prefs_matcher_open(MatcherList *matchers, PrefsMatcherSignal *cb)
 		prefs_matcher_create();
 	} else {
 		/* update color label menu */
-		gtk_option_menu_set_menu(GTK_OPTION_MENU(matcher.color_optmenu),
+		gtk_cmoption_menu_set_menu(GTK_CMOPTION_MENU(matcher.color_optmenu),
 				colorlabel_create_color_menu());
 	}
 
@@ -490,7 +493,9 @@ static void prefs_matcher_create(void)
 	GtkWidget *numeric_entry;
 	GtkWidget *numeric_label;
 	
+#ifndef G_OS_WIN32
 	GtkWidget *regexp_checkbtn;
+#endif
 	GtkWidget *case_checkbtn;
 
 	GtkWidget *reg_hbox;
@@ -622,7 +627,7 @@ static void prefs_matcher_create(void)
 	headers_combo = gtk_combo_box_entry_new_with_model(matcher.model_headers, 0);
 	gtk_widget_set_size_request(headers_combo, 100, -1);
 	gtk_box_pack_start(GTK_BOX(upper_hbox), headers_combo, TRUE, TRUE, 0);
-	header_entry = GTK_BIN (headers_combo)->child;
+	header_entry = gtk_bin_get_child(GTK_BIN((headers_combo)));
 	
 	criteria_combo2 = gtkut_sc_combobox_create(NULL, TRUE);
 	prefs_matcher_set_model(criteria_combo2, matcher.model_phrase);
@@ -655,8 +660,8 @@ static void prefs_matcher_create(void)
 	gtk_box_pack_start(GTK_BOX(match_hbox), match_combo, TRUE, TRUE, 0);
 	
 	/* color labels combo */
-	color_optmenu = gtk_option_menu_new();
-	gtk_option_menu_set_menu(GTK_OPTION_MENU(color_optmenu),
+	color_optmenu = gtk_cmoption_menu_new();
+	gtk_cmoption_menu_set_menu(GTK_CMOPTION_MENU(color_optmenu),
 				 colorlabel_create_color_menu());
 	gtk_box_pack_start(GTK_BOX(match_hbox), color_optmenu, FALSE, FALSE, 0);
 	
@@ -665,7 +670,7 @@ static void prefs_matcher_create(void)
 			      Q_("Filtering Matcher Menu|All"), _("Any"),
 			      "From", "To", "Cc", "Reply-To", "Sender", NULL);
 	gtk_box_pack_start(GTK_BOX(match_hbox), header_addr_combo, FALSE, FALSE, 0);
-	header_addr_entry = GTK_BIN(header_addr_combo)->child;
+	header_addr_entry = gtk_bin_get_child(GTK_BIN((header_addr_combo)));
 	gtk_widget_set_size_request(header_addr_combo, 150, -1);
 	
 	match_label2 = gtk_label_new("");
@@ -693,7 +698,9 @@ static void prefs_matcher_create(void)
 	hbox = gtk_hbox_new(FALSE, HSPACING_NARROW);
 	gtk_size_group_add_widget(size_group, hbox);
 	PACK_CHECK_BUTTON(hbox, case_checkbtn, _("Case sensitive"));
+#ifndef G_OS_WIN32
 	PACK_CHECK_BUTTON(hbox, regexp_checkbtn, _("Use regexp"));
+#endif
 	gtk_box_pack_end(GTK_BOX(hbox), gtk_label_new(""), TRUE, TRUE, 0);
 	gtk_table_attach(GTK_TABLE(table), hbox, 2, 3, 2, 3,
 			 GTK_FILL, GTK_SHRINK, 4, 0);
@@ -809,7 +816,9 @@ static void prefs_matcher_create(void)
 	matcher.addressbook_folder_combo = addressbook_folder_combo;
 	matcher.match_combo = match_combo;
 	matcher.case_checkbtn = case_checkbtn;
+#ifndef G_OS_WIN32
 	matcher.regexp_checkbtn = regexp_checkbtn;
+#endif
 	matcher.bool_op_combo = bool_op_combo;
 	matcher.test_btn = test_btn;
 	matcher.addressbook_select_btn = addressbook_select_btn;
@@ -867,13 +876,15 @@ static void prefs_matcher_reset_condition(void)
 	gtk_combo_box_set_active(GTK_COMBO_BOX(matcher.criteria_combo2), 0);
 	gtk_combo_box_set_active(GTK_COMBO_BOX(matcher.match_combo), 0);
 	gtk_combo_box_set_active(GTK_COMBO_BOX(matcher.match_combo2), 0);
-	gtk_option_menu_set_history(GTK_OPTION_MENU(matcher.color_optmenu), 0);
+	gtk_cmoption_menu_set_history(GTK_CMOPTION_MENU(matcher.color_optmenu), 0);
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(matcher.numeric_entry), 0);
 	gtk_entry_set_text(GTK_ENTRY(matcher.header_entry), "");
 	gtk_entry_set_text(GTK_ENTRY(matcher.header_addr_entry), "");
 	gtk_entry_set_text(GTK_ENTRY(matcher.string_entry), "");
-	gtk_entry_set_text(GTK_ENTRY(GTK_BIN(matcher.addressbook_folder_combo)->child), "");
+	gtk_entry_set_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN((matcher.addressbook_folder_combo)))), "");
+#ifndef G_OS_WIN32
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(matcher.regexp_checkbtn), FALSE);
+#endif
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(matcher.case_checkbtn), FALSE);
 }
 
@@ -1344,7 +1355,11 @@ static MatcherProp *prefs_matcher_dialog_to_matcher(void)
 	if(value_pred)
 		criteria = prefs_matcher_not_criteria(criteria);
 
+#ifndef G_OS_WIN32
 	use_regexp = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(matcher.regexp_checkbtn));
+#else
+	use_regexp = FALSE;
+#endif
 	case_sensitive = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(matcher.case_checkbtn));
 
 	if (use_regexp) {
@@ -1439,7 +1454,7 @@ static MatcherProp *prefs_matcher_dialog_to_matcher(void)
 		
 	case CRITERIA_COLORLABEL:
 		value = colorlabel_get_color_menu_active_item
-			(gtk_option_menu_get_menu(GTK_OPTION_MENU
+			(gtk_cmoption_menu_get_menu(GTK_CMOPTION_MENU
 				(matcher.color_optmenu))); 
 		break;
 
@@ -1460,7 +1475,7 @@ static MatcherProp *prefs_matcher_dialog_to_matcher(void)
 
 	case CRITERIA_FOUND_IN_ADDRESSBOOK:
 		header = gtk_entry_get_text(GTK_ENTRY(matcher.header_addr_entry));
-		expr = gtk_entry_get_text(GTK_ENTRY(GTK_BIN(matcher.addressbook_folder_combo)->child));
+		expr = gtk_entry_get_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN((matcher.addressbook_folder_combo)))));
 
 		if (*header == '\0') {
 		    alertpanel_error(_("Header name is not set."));
@@ -1708,15 +1723,19 @@ static void prefs_matcher_second_criteria_sel(GtkWidget *widget,
 			prefs_matcher_enable_widget(matcher.match_label2, TRUE);
 			prefs_matcher_enable_widget(matcher.string_entry, FALSE);
 			prefs_matcher_enable_widget(matcher.case_checkbtn, FALSE);
+#ifndef G_OS_WIN32
 			prefs_matcher_enable_widget(matcher.regexp_checkbtn, FALSE);
+#endif
 		} else {
 			prefs_matcher_enable_widget(matcher.upper_filler, TRUE);
 			prefs_matcher_enable_widget(matcher.match_label2, FALSE);
 			prefs_matcher_enable_widget(matcher.string_entry, TRUE);
 			prefs_matcher_enable_widget(matcher.case_checkbtn, TRUE);
+#ifndef G_OS_WIN32
 			prefs_matcher_enable_widget(matcher.regexp_checkbtn, TRUE);
 			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(
 						matcher.regexp_checkbtn), FALSE);
+#endif
 			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(
 						matcher.case_checkbtn), FALSE);
 		}
@@ -1787,8 +1806,10 @@ static void prefs_matcher_criteria_select(GtkWidget *widget,
 				    MATCH_COMBO_IS_ENABLED(value));
 	prefs_matcher_enable_widget(matcher.case_checkbtn,
 				    MATCH_CASE_REGEXP(value));
+#ifndef G_OS_WIN32
 	prefs_matcher_enable_widget(matcher.regexp_checkbtn,
 				    MATCH_CASE_REGEXP(value));
+#endif
 	prefs_matcher_enable_widget(matcher.test_btn,
 				    (value == MATCH_TEST));
 	prefs_matcher_enable_widget(matcher.addressbook_select_btn,
@@ -1831,11 +1852,13 @@ static void prefs_matcher_criteria_select(GtkWidget *widget,
 		prefs_matcher_set_model(matcher.match_combo, matcher.model_contain);
 		gtk_label_set_text(GTK_LABEL(matcher.criteria_label2), _("Name:"));
 		gtk_label_set_text(GTK_LABEL(matcher.match_label), _("Header"));
+#ifndef G_OS_WIN32
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(matcher.regexp_checkbtn), FALSE);
+#endif
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(matcher.case_checkbtn), FALSE);
 		break;
 	case MATCH_LABEL:
-		gtk_option_menu_set_history(GTK_OPTION_MENU(matcher.color_optmenu), 0);
+		gtk_cmoption_menu_set_history(GTK_CMOPTION_MENU(matcher.color_optmenu), 0);
 		prefs_matcher_set_model(matcher.match_combo2, matcher.model_set);
 		gtk_label_set_text(GTK_LABEL(matcher.match_label), _("Label"));
 		gtk_label_set_text(GTK_LABEL(matcher.match_label2), _("is"));
@@ -1848,7 +1871,9 @@ static void prefs_matcher_criteria_select(GtkWidget *widget,
 		prefs_matcher_set_model(matcher.criteria_combo2, matcher.model_phrase);
 		prefs_matcher_set_model(matcher.match_combo, matcher.model_contain);
 		gtk_label_set_text(GTK_LABEL(matcher.criteria_label2), _("in"));
+#ifndef G_OS_WIN32
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(matcher.regexp_checkbtn), FALSE);
+#endif
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(matcher.case_checkbtn), FALSE);
 		prefs_matcher_second_criteria_sel(NULL, NULL);
 		break;	
@@ -2039,10 +2064,10 @@ static void prefs_matcher_addressbook_select(void)
 	const gchar *folderpath = NULL;
 	gchar *new_path = NULL;
 
-	folderpath = gtk_entry_get_text(GTK_ENTRY(GTK_BIN(matcher.addressbook_folder_combo)->child));
+	folderpath = gtk_entry_get_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN((matcher.addressbook_folder_combo)))));
 	new_path = addressbook_folder_selection(folderpath);
 	if (new_path) {
-		gtk_entry_set_text(GTK_ENTRY(GTK_BIN(matcher.addressbook_folder_combo)->child), new_path);
+		gtk_entry_set_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN((matcher.addressbook_folder_combo)))), new_path);
 		g_free(new_path);
 	} 
 }
@@ -2344,7 +2369,7 @@ static gboolean prefs_matcher_selected(GtkTreeSelection *selector,
 			expr = prop->expr;
 
 		gtk_entry_set_text(GTK_ENTRY(matcher.header_addr_entry), header);
-		gtk_entry_set_text(GTK_ENTRY(GTK_BIN(matcher.addressbook_folder_combo)->child), expr);
+		gtk_entry_set_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN((matcher.addressbook_folder_combo)))), expr);
 		break;
 	}
 
@@ -2393,9 +2418,9 @@ static gboolean prefs_matcher_selected(GtkTreeSelection *selector,
 
 	case MATCHCRITERIA_NOT_COLORLABEL:
 	case MATCHCRITERIA_COLORLABEL:
-		gtk_option_menu_set_history(GTK_OPTION_MENU(matcher.color_optmenu),
+		gtk_cmoption_menu_set_history(GTK_CMOPTION_MENU(matcher.color_optmenu),
 					    prop->value);
-		menu = gtk_option_menu_get_menu(GTK_OPTION_MENU(matcher.color_optmenu));
+		menu = gtk_cmoption_menu_get_menu(GTK_CMOPTION_MENU(matcher.color_optmenu));
 		g_signal_emit_by_name(G_OBJECT(menu), "selection-done", menu);
 		break;
 
@@ -2459,22 +2484,30 @@ static gboolean prefs_matcher_selected(GtkTreeSelection *selector,
 
 	switch(prop->matchtype) {
 	case MATCHTYPE_MATCH:
+#ifndef G_OS_WIN32
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(matcher.regexp_checkbtn), FALSE);
+#endif
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(matcher.case_checkbtn), TRUE);
 		break;
 
 	case MATCHTYPE_MATCHCASE:
+#ifndef G_OS_WIN32
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(matcher.regexp_checkbtn), FALSE);
+#endif
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(matcher.case_checkbtn), FALSE);
 		break;
 
 	case MATCHTYPE_REGEXP:
+#ifndef G_OS_WIN32
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(matcher.regexp_checkbtn), TRUE);
+#endif
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(matcher.case_checkbtn), TRUE);
 		break;
 
 	case MATCHTYPE_REGEXPCASE:
+#ifndef G_OS_WIN32
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(matcher.regexp_checkbtn), TRUE);
+#endif
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(matcher.case_checkbtn), FALSE);
 		break;
 	}
